qiutil - common helper functions
================================

qiutil provides helper functions for the ohsu-qin projects.
See the `link documentation <http://qiutil.readthedocs.org/en/latest/>`_
for more information.
